@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Vocabulary::Applicator;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Implementation of the JSON Schema Applicator vocabulary
 
-our $VERSION = '0.554';
+our $VERSION = '0.555';
 
 use 5.020;
 use Moo;
@@ -565,7 +565,7 @@ JSON::Schema::Modern::Vocabulary::Applicator - Implementation of the JSON Schema
 
 =head1 VERSION
 
-version 0.554
+version 0.555
 
 =head1 DESCRIPTION
 
@@ -575,7 +575,7 @@ version 0.554
 
 Implementation of the JSON Schema Draft 2020-12 "Applicator" vocabulary, indicated in metaschemas
 with the URI C<https://json-schema.org/draft/2020-12/vocab/applicator> and formally specified in
-L<https://datatracker.ietf.org/doc/html/draft-bhutton-json-schema-01#section-10>.
+L<https://json-schema.org/draft/2020-12/json-schema-core.html#section-10>.
 
 Support is also provided for
 
