@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Vocabulary::Core;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Implementation of the JSON Schema Core vocabulary
 
-our $VERSION = '0.554';
+our $VERSION = '0.555';
 
 use 5.020;
 use Moo;
@@ -347,7 +347,7 @@ JSON::Schema::Modern::Vocabulary::Core - Implementation of the JSON Schema Core
 
 =head1 VERSION
 
-version 0.554
+version 0.555
 
 =head1 DESCRIPTION
 
@@ -357,7 +357,7 @@ version 0.554
 
 Implementation of the JSON Schema Draft 2020-12 "Core" vocabulary, indicated in metaschemas
 with the URI C<https://json-schema.org/draft/2020-12/vocab/core> and formally specified in
-L<https://datatracker.ietf.org/doc/html/draft-bhutton-json-schema-01#section-8>.
+L<https://json-schema.org/draft/2020-12/json-schema-core.html#section-8>.
 
 Support is also provided for
 
