@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Vocabulary::Unevaluated;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Implementation of the JSON Schema Unevaluated vocabulary
 
-our $VERSION = '0.554';
+our $VERSION = '0.555';
 
 use 5.020;
 use Moo;
@@ -174,7 +174,7 @@ JSON::Schema::Modern::Vocabulary::Unevaluated - Implementation of the JSON Schem
 
 =head1 VERSION
 
-version 0.554
+version 0.555
 
 =head1 DESCRIPTION
 
@@ -184,7 +184,7 @@ version 0.554
 
 Implementation of the JSON Schema Draft 2020-12 "Unevaluated" vocabulary, indicated in metaschemas
 with the URI C<https://json-schema.org/draft/2020-12/vocab/unevaluated> and formally specified in
-L<https://datatracker.ietf.org/doc/html/draft-bhutton-json-schema-01#section-11>.
+L<https://json-schema.org/draft/2020-12/json-schema-core.html#section-11>.
 
 Support is also provided for the equivalent Draft 2019-09 keywords in the
 JSON Schema Draft 2019-09 "Applicator" vocabulary, indicated in metaschemas
